/*
 * Filesystem client functions.
 *
 * Copyright (C) 2018, 2019, 2020, 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <fsclient/file.h>



EXTERN_C_BEGIN

/* Opening and closing operations. */

void client_close(file_t *file);
file_t *client_open(const char *name, flags_t flags);
file_t *client_open_using(const char *name, flags_t flags, const char *cap);
long client_pipe(file_t **reader, file_t **writer);
long client_pipe_using(file_t **reader, file_t **writer, const char *cap);

/* File and region operations. */

long client_flush(file_t *file);
void *client_mmap(file_t *file, offset_t position, offset_t length);

/* Pipe region operations. */

long client_current_region(file_t *file);
long client_next_region(file_t *file);

/* File data operations. */

offset_t client_read(file_t *file, void *buf, offset_t count);
offset_t client_write(file_t *file, const void *buf, offset_t count);

/* File navigation operations. */

offset_t client_seek(file_t *file, offset_t offset, int whence);
long client_tell(file_t *file);

/* Notification operations. */

long client_set_blocking(file_t *file, notify_flags_t flags);
long client_subscribe(file_t *file, notify_flags_t flags);
long client_unsubscribe(file_t *file);
long client_wait_file(file_t *file);
long client_wait_files(file_t **file);

EXTERN_C_END

// vim: tabstop=2 expandtab shiftwidth=2
